==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/audiotoolbox/MIDIChannelMessage.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.audiotoolbox;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.corefoundation.*;
import org.robovm.apple.audiounit.*;
import org.robovm.apple.coreaudio.*;
import org.robovm.apple.coremidi.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/MIDIChannelMessage/*</name>*/ 
    extends /*<extends>*/Struct<MIDIChannelMessage>/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class MIDIChannelMessagePtr extends Ptr<MIDIChannelMessage, MIDIChannelMessagePtr> {}/*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public MIDIChannelMessage() {}
    public MIDIChannelMessage(byte status, byte data1, byte data2) {
        this.setStatus(status);
        this.setData1(data1);
        this.setData2(data2);
    }
    /*</constructors>*/
    /*<properties>*//*</properties>*/
    /*<members>*/
    @StructMember(0) public native byte getStatus();
    @StructMember(0) public native MIDIChannelMessage setStatus(byte status);
    @StructMember(1) public native byte getData1();
    @StructMember(1) public native MIDIChannelMessage setData1(byte data1);
    @StructMember(2) public native byte getData2();
    @StructMember(2) public native MIDIChannelMessage setData2(byte data2);
    @StructMember(3) private native byte getReserved();
    @StructMember(3) private native MIDIChannelMessage setReserved(byte reserved);
    /*</members>*/
    /*<methods>*//*</methods>*/
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/audiotoolbox/MIDIChannelMessage.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.audiotoolbox;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.corefoundation.*;
import org.robovm.apple.coreaudio.*;
import org.robovm.apple.coremidi.*;
import org.robovm.apple.avfoundation.*;
import org.robovm.apple.uikit.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/MIDIChannelMessage/*</name>*/ 
    extends /*<extends>*/Struct<MIDIChannelMessage>/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class MIDIChannelMessagePtr extends Ptr<MIDIChannelMessage, MIDIChannelMessagePtr> {}/*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public MIDIChannelMessage() {}
    public MIDIChannelMessage(byte status, byte data1, byte data2) {
        this.setStatus(status);
        this.setData1(data1);
        this.setData2(data2);
    }
    /*</constructors>*/
    /*<properties>*//*</properties>*/
    /*<members>*/
    @StructMember(0) public native byte getStatus();
    @StructMember(0) public native MIDIChannelMessage setStatus(byte status);
    @StructMember(1) public native byte getData1();
    @StructMember(1) public native MIDIChannelMessage setData1(byte data1);
    @StructMember(2) public native byte getData2();
    @StructMember(2) public native MIDIChannelMessage setData2(byte data2);
    @StructMember(3) private native byte getReserved();
    @StructMember(3) private native MIDIChannelMessage setReserved(byte reserved);
    /*</members>*/
    /*<methods>*//*</methods>*/
}
